/* clicker_LDR.c 
 * run '$ make' to check for erors,
 * '$ make writeflash' to compile and upload
 */



#define F_CPU 1000000L // Define software reference clock for delay duration
#define LDR_1_THRESHOLD 200

#include <avr/io.h>
#include <util/delay.h>

#define TICKER PB1 // Define led ext output pin on PB2
#define LED1 PB0 
#define LED2 PB2
 
 int i; // 8 bits integer

void delay(int ms) {
  int i;
  for (i=0; i<ms; i++) {
    _delay_ms(1);
  }
}

int analog_read(int read_pin){
  //Read ADC2L:
  if(read_pin != 1 && read_pin != 2 && read_pin != 3){
    //if read_pin is not a valid number, break.
    return 0;
  }
  ADMUX |= read_pin; //set the pin that the adc reads to ADC2 (PB4)
  ADCSRA |= (1 << ADEN); // Analog-Digital enable bit
  ADCSRA |= (1 << ADSC); // Discard first conversion
  while (ADCSRA & (1 << ADSC)); // wait until conversion is done
  ADCSRA |= (1 << ADSC); // start single conversion
  while (ADCSRA & (1 << ADSC)) // wait until conversion is done
  ADCSRA &= ~(1<<ADEN); // shut down the ADC
  int low_val = ADCL;
  int high_val = ADCH;
  int val = (high_val<<8)|low_val;
  
  //Clear bottom 3 bits of ADMUX:
  ADMUX &= ~(0x111);
  return val;
}

void delay_microseconds(int us){
  int i;
  for(i=0; i<us; i++){
    _delay_us(1);
  }
}

void fake_pwm(int ten_bit, int pin, int ms_length){
  int remainder = 1023-ten_bit;
  int i;
    for(i = 0; i < (1000 * ms_length); i++){
      PORTB |= (1<<pin);
	  _delay_us(ten_bit);
	  PORTB &=~(1<<pin);
	  _delay_us(remainder);
	}
}

 int main(void){
   int reading_1 = 0;
   int reading_2 = 0;
   //takes one reading at startup as the light threshold that
   //the transistor will trigger (PB0 at the moment)
   int light_threshold = analog_read(3);
   DDRB |= (1 << TICKER); // Set output direction on LED
   DDRB |= (1 << LED1);
   ADCSRA |= (1 << ADEN)| // Analog-Digital enable bit
   // set prescaler to 8 (clock / 8) 
   (1 << ADPS1)|(1 << ADPS0);
   while(1){
	 reading_1 = analog_read(2);
	 //Blink the LEDs
	 if(reading_1 > light_threshold){
	   PORTB |= (1 << TICKER);
	   PORTB |= (1 << LED1);
	   delay(10);
	   PORTB &= ~(1 << TICKER);
	   delay(10);
	 }
	 else{
	   PORTB &= ~(1 << TICKER);
	   PORTB &= ~(1 << LED1);
	 }
	 //while(analog_read(2) > LDR_1_THRESHOLD){
	 //  PORTB &= ~(1 << TICKER);
	 //  PORTB |= ~(1 << LED1);
	 //} //hold until state changes below threshold
   }
   return 0;
 }
